@@ -134,29 +134,11 @@ L<GraphViz2::Parse::Yacc> - Visualize a yacc grammar as a graph
 
 	use GraphViz2;
 	use GraphViz2::Parse::Yacc;
-
-	use Log::Handler;
-
-	# ------------------------------------------------
-
-	my($logger) = Log::Handler -> new;
-
-	$logger -> add
-		(
-		 screen =>
-		 {
-			 maxlevel       => 'debug',
-			 message_layout => '%m',
-			 minlevel       => 'error',
-		 }
-		);
-
 	my($graph)  = GraphViz2 -> new
 		(
 		 edge   => {color => 'grey'},
 		 global => {directed => 1},
 		 graph  => {concentrate => 1, rankdir => 'TB'},
-		 logger => $logger,
 		 node   => {color => 'blue', shape => 'oval'},
 		);
 	my($g) = GraphViz2::Parse::Yacc -> new(graph => $graph);
